package blockchain
import (
	"fmt"
	"github.com/hyperledger/fabric-sdk-go/pkg/client/channel"
	"time"
)
// AddOperation
func (setup *FabricSetup) AddOperation(
	botId			string,	// robot's ID
	procId			string,	// process's ID
	operId			string,	// operation's ID
	operName		string,	// operation's name
	priority		string,	// operation's priority
	resourceLink	string, // link to the used resource
	startTimeArray	[]OperationStartTime, // Array of structs
	endTimeArray	[]string /* Array of strings*/) (string, error) {
	// Prepare arguments
	var args []string
	args = append(args, "invoke")
	args = append(args, "addOperation")
	args = append(args, botId)
	args = append(args, procId)
	args = append(args, operId)
	args = append(args, operName)
	args = append(args, priority)
	args = append(args, resourceLink)
	// Start and end time as string
	var stString string
	stString = ""
	for _, st := range startTimeArray {
		if stString != "" {
			stString += "/"
		}
		stString += st.Intensity + ";" + st.Value 
	}
	args = append(args, stString)
	stString = ""
	for _, st := range endTimeArray {
		if stString != "" {
			stString += "/"
		}
		stString += st 
	}
	args = append(args, stString)
	eventID := "eventInvoke"
	// Add data that will be visible in the proposal, like a description of the invoke request
	transientDataMap := make(map[string][]byte)
	transientDataMap["result"] = []byte("Transient data in operation invoke")
	reg, notifier, err := setup.event.RegisterChaincodeEvent(setup.ChainCodeID, eventID)
	if err != nil {
		return "", err
	}
	defer setup.event.Unregister(reg)
	// Create a request (proposal) and send it
	var invokeArgs [][]byte
	for i:=1; i<len(args); i++ {
		invokeArgs = append(invokeArgs, []byte(args[i]))
	}
	response, err := setup.client.Execute(channel.Request{ChaincodeID: setup.ChainCodeID, Fcn: args[0], Args: invokeArgs, TransientMap: transientDataMap})
	if err != nil {
		return "", fmt.Errorf("failed to move funds: %v", err)
	}
	// Wait for the result of the submission
	select {
	case ccEvent := <-notifier:
		fmt.Printf("Received CC event: %s\n", ccEvent)
	case <-time.After(time.Second * 20):
		return "", fmt.Errorf("did NOT receive CC event for eventID(%s)", eventID)
	}
	return string(response.TransactionID), nil
}
