package blockchain
import (
	"fmt"
	"github.com/hyperledger/fabric-sdk-go/pkg/client/channel"
	"time"
)
// AddResource
func (setup *FabricSetup) AddResource(
	botId		string,	// robot's ID
	resId		string,	// resource's ID
	worktime	string	/* worktime */) (string, error) {
	// Prepare arguments
	var args []string
	args = append(args, "invoke")
	args = append(args, "addResource")
	args = append(args, botId)
	args = append(args, resId)
	args = append(args, worktime)
	eventID := "eventInvoke"
	// Add data that will be visible in the proposal, like a description of the invoke request
	transientDataMap := make(map[string][]byte)
	transientDataMap["result"] = []byte("Transient data in operation invoke")
	reg, notifier, err := setup.event.RegisterChaincodeEvent(setup.ChainCodeID, eventID)
	if err != nil {
		return "", err
	}
	defer setup.event.Unregister(reg)
	// Create a request (proposal) and send it
	var invokeArgs [][]byte
	for i:=1; i<len(args); i++ {
		invokeArgs = append(invokeArgs, []byte(args[i]))
	}
	response, err := setup.client.Execute(channel.Request{ChaincodeID: setup.ChainCodeID, Fcn: args[0], Args: invokeArgs, TransientMap: transientDataMap})
	if err != nil {
		return "", fmt.Errorf("failed to move funds: %v", err)
	}
	// Wait for the result of the submission
	select {
	case ccEvent := <-notifier:
		fmt.Printf("Received CC event: %s\n", ccEvent)
	case <-time.After(time.Second * 20):
		return "", fmt.Errorf("did NOT receive CC event for eventID(%s)", eventID)
	}
	return string(response.TransactionID), nil
}
