package blockchain
import (
    "fmt"
	"github.com/hyperledger/fabric-sdk-go/pkg/client/channel"
)
type OperationStartTime struct {
	Intensity   string
	Value		string
}
func TestStartTimeArray() ([]OperationStartTime) {
	return []OperationStartTime{{Intensity: "5", Value: "12"}, {Intensity: "3", Value: "24"}}
}
func TestEndTimeArray() ([]string) {
	return []string{"15", "25"}
}
func TestScheduleXmlText() (string) {
	return `
	<spy:schedule>
 <spy:processes>
    <spy:Process id="1">
    <spy:operations>
    <spy:Operation id="1">
    <spy:name>Погрузка элемента №3 на платформу</spy:name>
    <spy:priority>0.3254</spy:priority>
    <spy:resource>RS_2</spy:resource>
    <spy:start>
       <spy:StartTime intensity="5">12</spy:StartTime>
       <spy:StartTime intensity="3">24</spy:StartTime>
    </spy:start>
    <spy:end>
       <spy:EndTime>15</spy:EndTime>
       <spy:EndTime>25</spy:EndTime>
    </spy:end>
    </spy:Operation>
    <spy:Operation id="2">
    <spy:name>Транспортировка элемента №3</spy:name>
    <spy:priority>0.5442</spy:priority>
    <spy:resource>RS_3</spy:resource>
    <spy:start>
       <spy:StartTime intensity="7">0</spy:StartTime>
       <spy:StartTime intensity="7">16</spy:StartTime>
       <spy:StartTime intensity="2">26</spy:StartTime>
    </spy:start>
    <spy:end>
       <spy:EndTime>11</spy:EndTime>
       <spy:EndTime>23</spy:EndTime>
       <spy:EndTime>31</spy:EndTime>
    </spy:end>
    </spy:Operation>
    </spy:operations>
    </spy:Process>
 </spy:processes>
 <spy:quality>
    <spy:Pki id="J0" generalized="True">
    <spy:weight>1</spy:weight>
    <spy:name>Обобщённый показатель качества</spy:name>
    <spy:val>270</spy:val>
    </spy:Pki>
    <spy:Pki id="J1" generalized="False">
    <spy:weight>0.8</spy:weight>
    <spy:name>Затраты энергии</spy:name>
    <spy:val>321</spy:val>
    </spy:Pki>
    <spy:Pki id="J2" generalized="False">
    <spy:weight>0.2</spy:weight>
    <spy:name>Затраты времени</spy:name>
    <spy:val>31</spy:val>
    </spy:Pki>
 </spy:quality>
 <spy:resources>
    <spy:Resource id="RS_2">
    <spy:worktime>12</spy:worktime>
    </spy:Resource>
    <spy:Resource id="RS_3">
    <spy:worktime>16</spy:worktime>
    </spy:Resource>
 </spy:resources>
 </spy:schedule>`
}
func NewOperationStartTime(intensity string, value string) (OperationStartTime) {
	return OperationStartTime{Intensity: intensity, Value: value}
}
func (setup *FabricSetup) getOperStateByName(stateName string, botId string, procId string, operId string) (string, error) {
	// Prepare arguments
	var args []string
	args = append(args, "invoke")
	args = append(args, "queryOperation")
	args = append(args, stateName)
	args = append(args, botId)
	args = append(args, procId)
	args = append(args, operId)
	var queryArgs [][]byte
	for i:=1; i<len(args); i++ {
		queryArgs = append(queryArgs, []byte(args[i]))
	}
	response, err := setup.client.Query(channel.Request{ChaincodeID: setup.ChainCodeID, Fcn: args[0], Args: queryArgs})
	if err != nil {
		return "", fmt.Errorf("failed to get %s: %v", stateName, err)
	}
	return string(response.Payload), nil
}
func (setup *FabricSetup) getPkiStateByName(stateName string, botId string, pkiId string) (string, error) {
	// Prepare arguments
	var args []string
	args = append(args, "invoke")
	args = append(args, "queryPki")
	args = append(args, stateName)
	args = append(args, botId)
	args = append(args, pkiId)
	var queryArgs [][]byte
	for i:=1; i<len(args); i++ {
		queryArgs = append(queryArgs, []byte(args[i]))
	}
	response, err := setup.client.Query(channel.Request{ChaincodeID: setup.ChainCodeID, Fcn: args[0], Args: queryArgs})
	if err != nil {
		return "", fmt.Errorf("failed to get %s: %v", stateName, err)
	}
	return string(response.Payload), nil
}
func (setup *FabricSetup) getResStateByName(stateName string, botId string, resourceId string) (string, error) {
	// Prepare arguments
	var args []string
	args = append(args, "invoke")
	args = append(args, "queryResource")
	args = append(args, stateName)
	args = append(args, botId)
	args = append(args, resourceId)
	var queryArgs [][]byte
	for i:=1; i<len(args); i++ {
		queryArgs = append(queryArgs, []byte(args[i]))
	}
	response, err := setup.client.Query(channel.Request{ChaincodeID: setup.ChainCodeID, Fcn: args[0], Args: queryArgs})
	if err != nil {
		return "", fmt.Errorf("failed to get %s: %v", stateName, err)
	}
	return string(response.Payload), nil
}