package blockchain
import (
	"fmt"
	"encoding/xml"
	"strings"
	"strconv"
)
// ScheduleSetup implementation
type ScheduleSetup struct {
	BotId			string
	Operations		[]OperationSetup
	Pkis			[]PkiSetup
	Resources		[]ResourceSetup
}
type ScheduleXML struct {
	XMLName		xml.Name		`xml:"schedule"`
	Processes	ProcessesXML	`xml:"processes"`
	Quality		QualityXML		`xml:"quality"`
	Resources 	ResourcesXML	`xml:"resources"`
}
type ProcessesXML struct {
	XMLName		xml.Name		`xml:"processes"`
	Processes	[]ProcessXML	`xml:"Process"`
}
type ProcessXML struct {
	XMLName		xml.Name		`xml:"Process"`
	Id 			string			`xml:"id,attr"`
	Operations 	OperationsXML 	`xml:"operations"`
}
// OperationSetup implementation
type OperationSetup struct {
	BotId			string
	ProcId			string
	Id				string
	Name			string
	Priority		string
	ResourceLink	string
	StartTimeArray	[]OperationStartTime
	EndTimeArray	[]string
}
type OperationsXML struct {
	XMLName 	xml.Name 		`xml:"operations"`
	Operations 	[]OperationXML 	`xml:"Operation"`
}
type OperationXML struct {
	XMLName 	xml.Name 		`xml:"Operation"`
	Id 			string			`xml:"id,attr"`
	Name 		string 			`xml:"name"`
	Priority	string 			`xml:"priority"`
	Resource 	string			`xml:"resource"`
	Start 		StartXML		`xml:"start"`
	End 		EndXML 			`xml:"end"`
}
type StartXML struct {
	XMLName 	xml.Name 		`xml:"start"`
	StartTime 	[]StartTimeXML 	`xml:"StartTime"`
}
type StartTimeXML struct {
	XMLName 	xml.Name 		`xml:"StartTime"`
	Intensity 	string 			`xml:"intensity,attr"`
	Data 		string			`xml:",chardata"`
}
type EndXML struct {
	XMLName 	xml.Name 		`xml:"end"`
	EndTime 	[]EndTimeXML 	`xml:"EndTime"`
}
type EndTimeXML struct {
	XMLName 	xml.Name 		`xml:"EndTime"`
	Data		string			`xml:",chardata"`
}
// PkiSetup implementation
type PkiSetup struct {
	BotId			string
	Id				string
	Name			string
	Generalized		bool
	Weight			string
	Value			string
}
type QualityXML struct {
	XMLName 	xml.Name 	`xml:"quality"`
	Pki 		[]PkiXML 	`xml:"Pki"`
}
type PkiXML struct {
	XMLName 	xml.Name 	`xml:"Pki"`
	Id 			string 		`xml:"id,attr"`
	Generalized		string 	`xml:"generalized,attr"`
	Weight 		string 		`xml:"weight"`
	Name		string 		`xml:"name"`
	Val 		string 		`xml:"val"`
}
// ResourceSetup implementation
type ResourceSetup struct {
	BotId			string
	Id				string
	Worktime		string
}
type ResourcesXML struct {
	XMLName 	xml.Name 	`xml:"resources"`
	Resources 	[]ResourceXML 	`xml:"Resource"`
}
type ResourceXML struct {
	XMLName 	xml.Name 	`xml:"Resource"`
	Id 			string 		`xml:"id,attr"`
	Worktime 	string 		`xml:"worktime"`
}
// Parser to my structs
func (setup *FabricSetup) ParseFromXML(xmlString string) []ScheduleSetup {
	var schedules	[]ScheduleSetup
	var schedule	ScheduleSetup
	var operation	OperationSetup
	var pki			PkiSetup
	var resource	ResourceSetup
	var operations	[]OperationSetup
	var pkis		[]PkiSetup
	var resources	[]ResourceSetup
	var scXml 		ScheduleXML
	var sta 		[]OperationStartTime
	var eta 		[]string
	xml.Unmarshal([]byte(strings.Replace(xmlString, "spy:", "", -1)), &scXml)
	for i:=1; i<2; i++ {
		botId := strconv.Itoa(i)
		proc := ""
		ido := ""
		nameo := ""
		priority := ""
		resl := ""
		for j:=0; j<len(scXml.Processes.Processes); j++ {
			proc = scXml.Processes.Processes[j].Id
			for k:=0; k<len(scXml.Processes.Processes[j].Operations.Operations); k++ {
				ido = scXml.Processes.Processes[j].Operations.Operations[k].Id
				nameo = scXml.Processes.Processes[j].Operations.Operations[k].Name
				priority = scXml.Processes.Processes[j].Operations.Operations[k].Priority
				resl = scXml.Processes.Processes[j].Operations.Operations[k].Resource
				for m:=0; m<len(scXml.Processes.Processes[j].Operations.Operations[k].Start.StartTime); m++ {
					sta = append(sta, NewOperationStartTime(scXml.Processes.Processes[j].Operations.Operations[k].Start.StartTime[m].Intensity,
										scXml.Processes.Processes[j].Operations.Operations[k].Start.StartTime[m].Data))
				}
				for m:=0; m<len(scXml.Processes.Processes[j].Operations.Operations[k].End.EndTime); m++ {
					eta = append(eta, scXml.Processes.Processes[j].Operations.Operations[k].End.EndTime[m].Data)
				}
				operation = OperationSetup{
					BotId:			botId,
					ProcId:			proc,
					Id:			ido,
					Name:			nameo,
					Priority:		priority,
					ResourceLink:	resl,
					StartTimeArray:	sta,
					EndTimeArray:	eta,
				}
				copy(operation.EndTimeArray, eta)
				operations = append(operations, operation)
				sta = []OperationStartTime{}
				eta = []string{}
			}
		}
		// Pkis
		idp := ""
		namep := ""
		gen := false
		weight := ""
		val := ""
		for j:=0; j<len(scXml.Quality.Pki); j++ {
			idp = scXml.Quality.Pki[j].Id
			namep = scXml.Quality.Pki[j].Name
			gen = isTrue(scXml.Quality.Pki[j].Generalized) 
			weight = scXml.Quality.Pki[j].Weight
			val = scXml.Quality.Pki[j].Val
			pki = PkiSetup{
				BotId:			botId,
				Id:			idp,
				Name:			namep,
				Generalized:		gen,
				Weight:			weight,
				Value:			val,
			}
			pkis = append(pkis, pki)
		}
		// Resources
		wt := ""
		for j:=0; j<len(scXml.Resources.Resources); j++ {
			wt = scXml.Resources.Resources[j].Worktime
			resource = ResourceSetup{
				BotId:			botId,
				Id:			scXml.Resources.Resources[j].Id,
				Worktime:		wt,
			}
			resources = append(resources, resource)
		}
		// Schedule
		schedule = ScheduleSetup{
			BotId:		botId,
			Operations:	operations,
			Pkis:		pkis,
			Resources:	resources,
		}
		copy(schedule.Operations, operations)
		copy(schedule.Pkis, pkis)
		copy(schedule.Resources, resources)
		schedules = append(schedules, schedule)
		operations = operations[:0]
		pkis = pkis[:0]
		resources = resources[:0]
	}
	return schedules
}
// Save from page to blockchain
func (setup *FabricSetup) ParseAndSave(xmlString string) (string, error) {
	schedules := setup.ParseFromXML(xmlString)
	response, err := setup.QueryHello()
	var responses []string
	if err != nil {
		fmt.Printf("Unable to query hello on the chaincode: %v\n", err)
		return "", err
	} else {
		fmt.Printf("Response from the query hello: %s\n", response)
	}
	for _, sc := range schedules {
		for _, op := range sc.Operations {
			response, err = setup.AddOperation(
				op.BotId,
				op.ProcId,
				op.Id,
				op.Name,
				op.Priority,
				op.ResourceLink,
				op.StartTimeArray,
				op.EndTimeArray)
			if err != nil {
				fmt.Printf("Unable to add the schedule on the chaincode: %v\n", err)
				return "", err
			}
			responses = append(responses,  response)
		}
		for _, pki := range sc.Pkis {
			response, err = setup.AddPki(
				pki.BotId,
				pki.Id,
				pki.Generalized,
				pki.Weight,
				pki.Name,
				pki.Value)
			if err != nil {
				fmt.Printf("Unable to add the schedule on the chaincode: %v\n", err)
				return "", err
			}
			responses = append(responses,  response)
		}
		for _, res := range sc.Resources {
			response, err = setup.AddResource(
				res.BotId,
				res.Id,
				res.Worktime)
			if err != nil {
				fmt.Printf("Unable to add the schedule on the chaincode: %v\n", err)
				return "", err
			}
			responses = append(responses,  response)
		}
	}
	return strings.Join(responses, ", "), nil
}
func isTrue(bString string) bool {
	var r bool
	switch bString {
	case "True":
		r = true
	case "true":
		r = true
	case "False":
		r = false
	case "false":
		r = false
	default:
		r = false
	}
	return r
}