package blockchain
import (
	"fmt"
)
func (setup *FabricSetup) GetScheduleHTML(scheduleId string) (string, error) {
	// Test Query the chaincode
	response, err := setup.QueryHello()
	if err != nil {
		fmt.Printf("Unable to query hello on the chaincode: %v\n", err)
	} else {
		fmt.Printf("Response from the query hello: %s\n", response)
	}
	// html
	blob := `<table border="2">`
	procs, err := setup.GetProcesses(scheduleId)
	if err != nil {
		return "failed to get html data Processes", err
	}
	var opers []string
	var sta []OperationStartTime
	var eta []string
	for i:=0; i<len(procs); i++ {
		if procs[i] == "" {
			continue
		}
		opers, err = setup.GetOperations(scheduleId, procs[i])
		if err != nil {
			return "failed to get html data Operations", err
		}
		for j:=0; j<len(opers); j++ {
			if opers[j] == "" {
				continue
			}
			response, err = setup.GetOperationName(scheduleId, procs[i], opers[j])
			if err != nil {
				fmt.Printf("Unable to query Operation Name on the chaincode: %v\n", err)
			} else {
				blob = blob + `<tr><td>Operation name</td><td>` + response + `</td></tr>`
			}
			response, err = setup.GetOperationPriority(scheduleId, procs[i], opers[j])
			if err != nil {
				fmt.Printf("Unable to query Operation Priority on the chaincode: %v\n", err)
			} else {
				blob = blob + `<tr><td>Operation priority</td><td>` + response + `</td></tr>`
			}
			response, err = setup.GetOperationResourceLink(scheduleId, procs[i], opers[j])
			if err != nil {
				fmt.Printf("Unable to query Operation Resource on the chaincode: %v\n", err)
			} else {
				blob = blob + `<tr><td>Operation resource</td><td>` + response + `</td></tr>`
			}
			sta, err = setup.GetStartTimeArray(scheduleId, procs[i], opers[j])
			if err != nil {
				fmt.Printf("Unable to query Operation Start Time on the chaincode: %v\n", err)
			} else {
				for _, st := range sta {
					blob = blob + `<tr><td>Start Time</td><td>` + st.Intensity + `/` + st.Value + `</td></tr>`
				}
			}
			eta, err = setup.GetEndTimeArray(scheduleId, procs[i], opers[j])
			if err != nil {
				fmt.Printf("Unable to query Operation Start Time on the chaincode: %v\n", err)
			} else {
				for _, et := range eta {
					blob = blob + `<tr><td>End Time</td><td>` + et + `</td></tr>`
				}
			}
		}
	}
	pkis, err := setup.GetPkis(scheduleId)
	if err != nil {
		return "failed to get html data Pki", err
	}
	gnrl := false
	for i:=0; i<len(pkis); i++ {
		if pkis[i] == "" {
			continue
		}
		response, err = setup.GetPkiName(scheduleId, pkis[i])
		if err != nil {
			fmt.Printf("Unable to query Pki's Name on the chaincode: %v\n", err)
		} else {
			blob = blob + `<tr><td>Pki name</td><td>` + response + `</td></tr>`
		}
		gnrl, err = setup.GetPkiGeneralized(scheduleId, pkis[i])
		if err != nil {
			fmt.Printf("Unable to query Pki's Generalized on the chaincode: %v\n", err)
		} else if gnrl {
			blob = blob + `<tr><td>Pki generalized</td><td>True</td></tr>`
		} else {
			blob = blob + `<tr><td>Pki generalized</td><td>False</td></tr>`
		}
		response, err = setup.GetPkiWeight(scheduleId, pkis[i])
		if err != nil {
			fmt.Printf("Unable to query Pki's Weight on the chaincode: %v\n", err)
		} else {
			blob = blob + `<tr><td>Pki weight</td><td>` + response + `</td></tr>`
		}
		response, err = setup.GetPkiValue(scheduleId, pkis[i])
		if err != nil {
			fmt.Printf("Unable to query Pki's Value on the chaincode: %v\n", err)
		} else {
			blob = blob + `<tr><td>Pki value</td><td>` + response + `</td></tr>`
		}
	}
	rs, err := setup.GetResources(scheduleId)
	if err != nil {
		return "failed to get html data Resource", err
	}
	for i:=0; i<len(rs); i++ {
		if rs[i] == "" {
			continue
		}
		blob = blob + `<tr><td>Resource id</td><td>` + rs[i] + `</td></tr>`
		response, err = setup.GetResourceWorktime(scheduleId, rs[i])
		if err != nil {
			fmt.Printf("Unable to query Resource's Worktime on the chaincode: %v\n", err)
		} else {
			blob = blob + `<tr><td>Resource worktime</td><td>` + response + `</td></tr>`
		}
	}
	blob = blob + `</table>`
	return blob, nil
}