package controllers

import (
	"net/http"
	"html/template"
)

func (app *Application) RequestHandler(w http.ResponseWriter, r *http.Request) {
	data := &struct {
		TransactionId string
		Success       bool
		Response      bool
	}{
		TransactionId: "",
		Success:       false,
		Response:      false,
	}
	if r.FormValue("submitted") == "true" {
		helloValue := r.FormValue("hello")
		txid, err := app.Fabric.InvokeHello(helloValue)
		if err != nil {
			http.Error(w, "Unable to invoke hello in the blockchain", 500)
		}
		data.TransactionId = txid
		data.Success = true
		data.Response = true
	}
	renderTemplate(w, r, "request.html", data)
}

func (app *Application) ScheduleSetHandler(w http.ResponseWriter, r *http.Request) {
	data := &struct {
		TransactionId string
		Success       bool
		Response      bool
	}{
		TransactionId: "",
		Success:       false,
		Response:      false,
	}
	if r.FormValue("submitted") == "true" {
		scheduleXML := r.FormValue("xml")
		txid, err := app.Fabric.ParseAndSave(scheduleXML)
		if err != nil {
			http.Error(w, "Unable to invoke hello in the blockchain", 500)
		}
		data.TransactionId = txid
		data.Success = true
		data.Response = true
	}
	renderTemplate(w, r, "scheduleset.html", data)
}

func (app *Application) ScheduleGetHandler(w http.ResponseWriter, r *http.Request) {
	data := &struct {
		ScheduleHTML	template.HTML
		Success       	bool
		Response      	bool
	}{
		ScheduleHTML: 	template.HTML(""),
		Success:       	false,
		Response:      	false,
	}
	if r.FormValue("submitted") == "true" {
		scheduleId := r.FormValue("scheduleId")
		txsc, err := app.Fabric.GetScheduleHTML(scheduleId)
		if err != nil {
			http.Error(w, "Unable to invoke hello in the blockchain", 500)
		}
		data.ScheduleHTML = template.HTML(txsc)
		data.Success = true
		data.Response = true
	}
	renderTemplate(w, r, "scheduleget.html", data)
}
